entity_graph_provider

Function entity_graph_provider 

pub fn entity_graph_provider(
    catalog_manager: &Weak<dyn CatalogManager>,
) -> Result<Option<EntityGraphProviderRef>>
Try to get the entity-graph provider from a [CatalogManager] weak reference. Returns None when the manager is not the kv-backed one or the provider has not been injected yet (the computed graph tables then stream empty).